Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ContributionVO ¶
type ContributionVO struct {
ID string `json:"id" jsonapi:"primary,contribution"`
Person *PersonVO `json:"person,omitempty" jsonapi:"relation,person,omitempty"`
Volume *VolumeVO `json:"volume,omitempty" jsonapi:"relation,volume,omitempty"`
Roles []string `jsonapi:"attr,roles"`
Notes string `json:"notes" jsonapi:"attr,notes"`
modelcore.AuditableVO
}
Contribution value object. This value object is a serializable representation of the Contribution model.
type LicenseVO ¶
type LicenseVO struct {
ID string `json:"id" jsonapi:"primary,license"`
Title string `json:"title" jsonapi:"attr,title"`
ShortTitle string `json:"short_title" jsonapi:"attr,short_title"`
Version string `json:"version" jsonapi:"attr,version"`
Deed string `json:"deed" jsonapi:"attr,deed"`
LegalCode string `json:"legal_code" jsonapi:"attr,legal_code"`
Website url.URL `json:"website" jsonapi:"attr,website"`
Status string `json:"status" jsonapi:"attr,status"`
Availability string `json:"availability" jsonapi:"attr,availability"`
Notes string `json:"notes" jsonapi:"attr,notes"`
Properties []modelcore.PropertyVO `json:"properties" jsonapi:"attr,properties"`
Tags []modelcore.TagVO `json:"tags" jsonapi:"attr,tags"`
modelcore.AuditableVO
}
License value object. This value object is a serializable representation of the License model.
type PersonVO ¶
type PersonVO struct {
ID string `json:"id" jsonapi:"primary,person"`
Name string `json:"name" jsonapi:"attr,name"`
Notes string `json:"notes" jsonapi:"attr,notes"`
Properties []modelcore.PropertyVO `json:"properties" jsonapi:"attr,properties"`
Tags []modelcore.TagVO `json:"tags" jsonapi:"attr,tags"`
modelcore.AuditableVO
}
Person value object. This value object is a serializable representation of the Person model.
type PublisherVO ¶
type PublisherVO struct {
ID string `json:"id" jsonapi:"primary,publisher"`
Name string `json:"name" jsonapi:"attr,name"`
Address string `json:"address" jsonapi:"attr,address"`
Website url.URL `json:"website" jsonapi:"attr,website"`
Notes string `json:"notes" jsonapi:"attr,notes"`
Properties []modelcore.PropertyVO `json:"properties" jsonapi:"attr,properties"`
Tags []modelcore.TagVO `json:"tags" jsonapi:"attr,tags"`
modelcore.AuditableVO
}
Publisher value object. This value object is a serializable representation of the Publisher model.
type ReviewVO ¶
type ReviewVO struct {
ID string `json:"id" jsonapi:"primary,review"`
Title string `json:"title" jsonapi:"attr,title"`
Body string `json:"body" jsonapi:"attr,body"`
Language string `json:"language" jsonapi:"attr,language"`
Volume *VolumeVO `json:"volume" jsonapi:"relation,volume"`
Notes string `json:"notes" jsonapi:"attr,notes"`
Tags []modelcore.TagVO `json:"tags" jsonapi:"attr,tags"`
modelcore.AuditableVO
}
Review value object. This value object is a serializable representation of the Review model.
type StudioVO ¶
type StudioVO struct {
ID string `json:"id" jsonapi:"primary,studio"`
Name string `json:"name" jsonapi:"attr,name"`
Website url.URL `json:"website" jsonapi:"attr,website"`
Notes string `json:"notes" jsonapi:"attr,notes"`
Properties []modelcore.PropertyVO `json:"properties" jsonapi:"attr,properties"`
Tags []modelcore.TagVO `json:"tags" jsonapi:"attr,tags"`
modelcore.AuditableVO
}
Studio value object. This value object is a serializable representation of the Studio model.
type SystemVO ¶
type SystemVO struct {
ID string `json:"id" jsonapi:"primary,system"`
GameSystem string `json:"game_system" jsonapi:"attr,game_system"`
Edition string `json:"edition" jsonapi:"attr,edition"`
Notes string `json:"notes" jsonapi:"attr,notes"`
Tags []modelcore.TagVO `json:"tags" jsonapi:"attr,tags"`
modelcore.AuditableVO
}
System value object. This value object is a serializable representation of the System model.
type VolumeVO ¶
type VolumeVO struct {
ID string `json:"id" jsonapi:"primary,volume"`
Title string `json:"title" jsonapi:"attr,title"`
Description string `json:"description" jsonapi:"attr,description"`
Notes string `json:"notes" jsonapi:"attr,notes"`
Systems []SystemVO `json:"systems" jsonapi:"relation,system"`
Publishers []PublisherVO `json:"publishers" jsonapi:"relation,publisher"`
Studios []StudioVO `json:"studios" jsonapi:"relation,studio"`
Licenses []LicenseVO `json:"licenses" jsonapi:"relation,license"`
Properties []modelcore.PropertyVO `json:"properties" jsonapi:"attr,properties"`
Tags []modelcore.TagVO `json:"tags" jsonapi:"attr,tags"`
modelcore.AuditableVO
}
Volume value object. This value object is a serializable representation of the Volume model.